<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="97"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="99"/>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="101"/>
        <source>Shortcuts:</source>
        <translation>Atalhos:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="113"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="213"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="219"/>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="138"/>
        <source>Add Command</source>
        <translation>Adicionar comando</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="147"/>
        <source>Edit Command</source>
        <translation>Editar comando</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="157"/>
        <source>Delete Command</source>
        <translation>Excluir comando</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="178"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="180"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="182"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="624"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="380"/>
        <source>Please enter a name</source>
        <translation>Digite um nome</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="394"/>
        <source>Please enter a command</source>
        <translation>Digite um comando</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="444"/>
        <source>The name already exists,</source>
        <translation>O nome já existe,</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="445"/>
        <source>please input another one.</source>
        <translation>insira outro.</translation>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="196"/>
        <source>Add Command</source>
        <translation>Adicionar comando</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="200"/>
        <source>No commands yet</source>
        <translation>Nenhum comando</translation>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="35"/>
        <source>Custom commands</source>
        <translation>Comandos personalizados</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="132"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="238"/>
        <source>Custom Theme</source>
        <translation>Tema Personalizado</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="262"/>
        <source>Style:</source>
        <translation>Estilo:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="266"/>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="271"/>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="325"/>
        <source>Fore color:</source>
        <translation>Cor de frente:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="332"/>
        <source>Back color:</source>
        <translation>Cor de fundo:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="350"/>
        <source>Prompt PS1:</source>
        <translation>Prompt PS1:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="354"/>
        <source>Prompt PS2:</source>
        <translation>Prompt PS2:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="424"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>GroupConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="39"/>
        <source>Group Name(Required)</source>
        <translation>Nome do Grupo (Obrigatório)</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="41"/>
        <source>Add Group</source>
        <translation>Adicionar grupo</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="44"/>
        <source>Edit Group</source>
        <translation>Editar grupo</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="60"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="61"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="61"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="65"/>
        <source>Please enter a group name</source>
        <translation>Insira um nome para o grupo</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="69"/>
        <source>The name should be no more than 30 characters</source>
        <translation>O nome não deve ter mais de 30 caracteres</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="868"/>
        <source>Delete Server</source>
        <translation>Excluir servidor</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="870"/>
        <source>Delete Custom Command</source>
        <translation>Apagar Comando Customizado</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="873"/>
        <source>Cancel Server Group</source>
        <translation>Cancelar Grupo de Servidores</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="882"/>
        <source>Ungrouped servers will go back to server list!</source>
        <translation>Servidores desagrupados voltarão para a lista de servidores!</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="498"/>
        <location filename="../src/views/listview.cpp" line="880"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Excluir %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="224"/>
        <location filename="../src/main/mainwindow.cpp" line="276"/>
        <source>New window</source>
        <translation>Nova janela</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="291"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="702"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="704"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1752"/>
        <source>Type path to download file</source>
        <translation>Digite o caminho para baixar o arquivo</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2049"/>
        <source>Custom Theme</source>
        <translation>Tema Personalizado</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="17"/>
        <source>Copy on select</source>
        <translation>Copiar ao selecionar</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="19"/>
        <source>Cursor blink</source>
        <translation>Intermitência do cursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="21"/>
        <source>Cursor style</source>
        <translation>Estilo do cursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="23"/>
        <source>Scroll on keystroke</source>
        <translation>Rolar ao teclar</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="25"/>
        <source>Scroll on output</source>
        <translation>Rolar na saída</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="27"/>
        <source>Allow Ctrl+scrollwheel to zoom text size</source>
        <translation>Permiti que Ctrl + Scroll amplie o tamanho do texto</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="29"/>
        <source>Hide Quake window after losing focus</source>
        <translation>Ocultar a janela Quake após perder o foco</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="31"/>
        <source>Quake window animation speed</source>
        <translation>Velocidade de animação da janela Quake</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="145"/>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Blur background</source>
        <translation>Desfocar o fundo</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="214"/>
        <source>debuginfod URLs</source>
        <translation>URLs do debuginfod</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Use on starting</source>
        <translation>Utilizar na inicialização</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Font size</source>
        <translation>Tamanho da fonte</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="176"/>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Opacity</source>
        <translation>Opacidade</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Scroll</source>
        <translation>Rolagem</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1594"/>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1592"/>
        <location filename="../src/main/mainwindow.cpp" line="2183"/>
        <location filename="../src/main/terminalapplication.cpp" line="25"/>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Workspace</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Custom commands</source>
        <translation>Comandos personalizados</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Remote management</source>
        <translation>Gerenciamento remoto</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <source>New tab</source>
        <translation>Nova aba</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Next tab</source>
        <translation>Próxima aba</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <source>Previous tab</source>
        <translation>Aba anterior</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Select left workspace</source>
        <translation>Selecionar o espaço de trabalho esquerdo</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <source>Select lower workspace</source>
        <translation>Selecionar o espaço de trabalho inferior</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <source>Select right workspace</source>
        <translation>Selecionar o espaço de trabalho direito</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <source>Select upper workspace</source>
        <translation>Selecionar o espaço de trabalho superior</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <source>Tab titles</source>
        <translation>Títulos das abas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <source>Go to tab 1</source>
        <translation>Ir para a aba 1</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <source>Go to tab 2</source>
        <translation>Ir para a aba 2</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <source>Go to tab 3</source>
        <translation>Ir para a aba 3</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Go to tab 4</source>
        <translation>Ir para a aba 4</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Go to tab 5</source>
        <translation>Ir para a aba 5</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Go to tab 6</source>
        <translation>Ir para a aba 6</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <source>Go to tab 7</source>
        <translation>Ir para a aba 7</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <source>Go to tab 8</source>
        <translation>Ir para a aba 8</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <source>Go to tab 9</source>
        <translation>Ir para a aba 9</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation>Desative o controle de fluxo usando Ctrl+S, Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <source>Shell profile</source>
        <translation>Perfil do shell</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <source>History size</source>
        <translation>Tamanho do histórico</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <source>Include special character(s) in double click selections</source>
        <translation>Incluir caracteres especiais nas seleções de clique duplo</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <source>Allow Ctrl + left mouse click to set cursor position</source>
        <translation>Permitir que Ctrl + Botão Esquerdo do Mouse defina a posição do cursor</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <source>The HTTP file server used for transmitting debugging information resources</source>
        <translation>O servidor de arquivos HTTP usado para transmitir recursos de informações de depuração</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/views/tabbar.cpp" line="486"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="208"/>
        <source>Rename title</source>
        <translation>Renomear título</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <source>Default size</source>
        <translation>Tamanho padrão</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <source>Select all</source>
        <translation>Selecionar tudo</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <source>Jump to next command</source>
        <translation>Ir para o próximo comando</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <source>Jump to previous command</source>
        <translation>Ir para o comando anterior</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <source>Zoom in</source>
        <translation>Aumentar zoom</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <source>Zoom out</source>
        <translation>Reduzir zoom</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Close other windows</source>
        <translation>Fechar outras janelas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Close other workspaces</source>
        <translation>Fechar outros espaços de trabalho</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1247"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation>Impossível encontrar &quot;%1&quot;, iniciando com &quot;%2&quot; em vez disso. Verifique o perfil do shell.</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1253"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation>Impossível abrir &quot;% 1&quot;, impossível executá-lo</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1255"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation>Impossível localizar &quot;% 1&quot;, não foi possível executá-lo</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1298"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation>A saída foi suspensa ao pressionar Ctrl+S. Pressionando Ctrl+Q irá retomar.</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Close window</source>
        <translation>Fechar janela</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <location filename="../src/views/termwidget.cpp" line="496"/>
        <source>Close workspace</source>
        <translation>Fechar espaço de trabalho</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <source>Horizontal split</source>
        <translation>Dividir horizontalmente</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <source>Vertical split</source>
        <translation>Dividir verticalmente</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <source>Find</source>
        <translation>Localizar</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="263"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="627"/>
        <location filename="../src/main/service.cpp" line="416"/>
        <source>please set another one.</source>
        <translation>Defina outro.</translation>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="28"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>O Terminal é um emulador de terminal avançado com espaço de trabalho, múltiplas janelas, gerenciamento remoto, modo quake e outros recursos.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1590"/>
        <source>Tabs</source>
        <translation>Abas</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/views/tabbar.cpp" line="480"/>
        <source>Close tab</source>
        <translation>Fechar aba</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <source>Select tab</source>
        <translation>Selecionar aba</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1610"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation>Alterar o foco para o ícone &quot;+&quot;</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="157"/>
        <location filename="../src/main/mainwindow.cpp" line="1698"/>
        <source>Select file to upload</source>
        <translation>Selecionar arquivo para enviar</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="162"/>
        <location filename="../src/main/mainwindow.cpp" line="1705"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="230"/>
        <source>Programs are still running in terminal</source>
        <translation>Alguns programas estão sendo executados no terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="182"/>
        <location filename="../src/common/utils.cpp" line="216"/>
        <source>Close this terminal?</source>
        <translation>Fechar este terminal?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="217"/>
        <source>There is still a process running in this terminal. Closing the terminal will terminate it.</source>
        <translation>Ainda há um processo em execução neste terminal. Fechar o terminal irá encerrá-lo.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="187"/>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will terminate all of them.</source>
        <translation>Ainda há %1 processos em execução neste terminal. Fechar o terminal encerrará todos eles.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="192"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>Close this window?</source>
        <translation>Fechar esta janela?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="193"/>
        <location filename="../src/common/utils.cpp" line="213"/>
        <source>There are still processes running in this window. Closing the window will terminate all of them.</source>
        <translation>Ainda há processos em execução neste terminal janela. Fechar a janela encerrará todos eles.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="136"/>
        <location filename="../src/main/mainwindow.cpp" line="1768"/>
        <source>Select a directory to save the file</source>
        <translation>Selecione um diretório para salvar o arquivo</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="230"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>Desinstalá-lo?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="243"/>
        <location filename="../src/common/utils.cpp" line="247"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation>Desinstalar este aplicativo?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="244"/>
        <location filename="../src/common/utils.cpp" line="248"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation>Você não poderá mais usar o Terminal.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="253"/>
        <location filename="../src/views/listview.cpp" line="499"/>
        <location filename="../src/views/listview.cpp" line="893"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="254"/>
        <location filename="../src/common/utils.cpp" line="298"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Execute a command in the terminal</source>
        <translation>Executar um comando no terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="341"/>
        <source>Run script string in the terminal</source>
        <translation>Executar o conjunto de scripts no terminal</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Set the work directory</source>
        <translation>Definir o diretório de trabalho</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Set the window mode on starting</source>
        <translation>Definir o modo de janela ao iniciar</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="344"/>
        <source>Run in quake mode</source>
        <translation>Executar no modo quake</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="347"/>
        <source>Keep terminal open when command finishes</source>
        <translation>Manter o terminal aberto quando o comando finalizar</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="387"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="476"/>
        <source>The name should be no more than 32 characters</source>
        <translation>O nome não deve ter mais do que 32 caracteres</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="142"/>
        <location filename="../src/main/mainwindow.cpp" line="1774"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="546"/>
        <source>Select</source>
        <translation>Selecionar</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="542"/>
        <source>Select the private key file</source>
        <translation>Selecionar o arquivo da chave privada</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="111"/>
        <source>Tab title format</source>
        <translation>Formato do título da aba</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="113"/>
        <source>Remote tab title format</source>
        <translation>Formato do título da aba remota</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/views/tabbar.cpp" line="483"/>
        <source>Close other tabs</source>
        <translation>Fechar as outras abas</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="894"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="500"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="245"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="210"/>
        <source>Add Group</source>
        <translation>Adicionar grupo</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="211"/>
        <source>Add Server</source>
        <translation>Adicionar servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="215"/>
        <source>No servers yet</source>
        <translation>Nenhum comando</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="75"/>
        <source>Remote management</source>
        <translation>Gerenciamento remoto</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="201"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation>Antes de clicar com o botão direito para enviar e baixar os arquivos; verifique se os comandos rz e sz estão instalados no servidor.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="211"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>ServerConfigManager</name>
    <message>
        <location filename="../src/remotemanage/serverconfigmanager.cpp" line="87"/>
        <source>Groups</source>
        <translation>Grupos</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigmanager.cpp" line="88"/>
        <source>Servers</source>
        <translation>Servidores</translation>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="91"/>
        <source>Add Server</source>
        <translation>Adicionar servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="127"/>
        <source>Server name:</source>
        <translation>Nome do servidor:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="129"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="139"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="167"/>
        <source>Required</source>
        <translation>Obrigatório</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="137"/>
        <source>Address:</source>
        <translation>Endereço:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="165"/>
        <source>Username:</source>
        <translation>Nome de usuário:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="172"/>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="178"/>
        <source>Certificate:</source>
        <translation>Certificado:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="185"/>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>No Group</source>
        <translation>Não há grupo</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="193"/>
        <source>Path:</source>
        <translation>Caminho:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="199"/>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="205"/>
        <source>Encoding:</source>
        <translation>Codificação:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Backspace key:</source>
        <translation>Tecla backspace:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Delete key:</source>
        <translation>Excluir chave:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="224"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="228"/>
        <source>Edit Server</source>
        <translation>Editar servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="470"/>
        <source>Please enter a server name</source>
        <translation>Digite o nome do servidor</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="483"/>
        <source>Please enter an IP address</source>
        <translation>Digite um endereço de IP</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="488"/>
        <source>Please enter a port</source>
        <translation>Digite uma porta</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="494"/>
        <source>Please enter a username</source>
        <translation>Digite um nome de usuário</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="508"/>
        <source>The server name already exists,</source>
        <translation>O nome do servidor já existe,</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="509"/>
        <source>please input another one. </source>
        <translation>insira outro.</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="412"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Split screen</source>
        <translation>Tela dividida</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Normal window</source>
        <translation>Janela normal</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Maximum</source>
        <translation>Maximizado</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="722"/>
        <source>Fast</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="726"/>
        <source>Slow</source>
        <translation>Lento</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="268"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="277"/>
        <source>The shortcut %1 is invalid, </source>
        <translation>O atalho %1 é inválido, </translation>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="284"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="291"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="297"/>
        <source>The shortcut %1 was already in use, </source>
        <translation>O atalho %1 já está em uso, </translation>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="42"/>
        <source>Insert</source>
        <translation>Inserir</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="88"/>
        <source>username: %u</source>
        <translation>nome de usuário: %u</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <source>username@: %U</source>
        <translation>nome de usuário@: %U</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <source>remote host: %h</source>
        <translation>host remoto: %h</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="75"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="87"/>
        <source>session number: %#</source>
        <translation>número da sessão: %#</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="75"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="89"/>
        <source>title set by shell: %w</source>
        <translation>título definido pelo shell: %w</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="86"/>
        <source>program name: %n</source>
        <translation>nome do programa: %n</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="86"/>
        <source>current directory (short): %d</source>
        <translation>diretório atual (abreviado): %d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="87"/>
        <source>current directory (long): %D</source>
        <translation>diretório atual (longo): %D</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="88"/>
        <source>local host: %h</source>
        <translation>host local: %h</translation>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="469"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="472"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="481"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="485"/>
        <source>Open in file manager</source>
        <translation>Abrir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="490"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Horizontal split</source>
        <translation>Dividir horizontalmente</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="492"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Vertical split</source>
        <translation>Dividir verticalmente</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="503"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>New tab</source>
        <translation>Nova aba</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="510"/>
        <source>Exit fullscreen</source>
        <translation>Sair da tela cheia</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="512"/>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="515"/>
        <source>Find</source>
        <translation>Localizar</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="519"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="529"/>
        <source>Encoding</source>
        <translation>Codificação</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="531"/>
        <source>Custom commands</source>
        <translation>Comandos personalizados</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Remote management</source>
        <translation>Gerenciamento remoto</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Upload file</source>
        <translation>Enviar arquivo</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="538"/>
        <source>Download file</source>
        <translation>Baixar arquivo</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="543"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1200"/>
        <source>The debuginfod settings will be effective after restart</source>
        <translation>As configurações do debuginfod serão aplicadas após a reinicialização</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="198"/>
        <location filename="../src/common/utils.cpp" line="232"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="200"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="233"/>
        <location filename="../src/common/utils.cpp" line="265"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Ok</translation>
    </message>
</context>
</TS>